/*
BATHINOV-PARAMETRIC-FRENCH-V2
par :
Philippe LECA - 2015-07-30
http://www.astrokraken.fr
leca.philippe@neuf.fr

Evolutions par rapport à la version précédente :
- calcul du nombre des fentes en fonction de la focale,
- ressources utiles et commentaires sur le "Bahtinov factor".


Ressource très utile :
http://astrojargon.net/MaskGenerator.aspx

The general rule to holes width is f/s=150-200,
where  :
    f is focal length,
    s is hole step size.
So for telescope with 1500mm focal length the step size is 1500/150=10mm 
(5mm hole, 5mm for uncut space).
If holes become too small the formula becomes 3f/s=150-200.
eg for 800mm scope you need to cut 2400/s=200 s=2400/200=12mm 
(6mm cut +6mm uncut).
The angled cuts are placed at 40 degrees to each other. 
*/

// paramètres généraux ---------------------------
angle=20;
epmask=2;
epbouchon=3;
douverture=140;
focale=1500;
bahtinovfactor=150;

// géométrie du bouchon ---------------------------
dintbouchon=144.2;
dextbouchon=dintbouchon+2*epbouchon;
profbouchon=8; // mettre "=epbouchon" si l'on ne veut pas de rebord

// pour MAK ou SCT : géométrie du trou central ----
dinttroucentral=0; // mettre à 0 si absence de trou central
danneaucentral=54; // mettre à 0 si absence de trou central

// caractéristiques des fentes --------------------
largfente=(focale/bahtinovfactor)/2; // largeur des fentes
largfils=largfente; // largeur des fils
suprfentexternes=1; // suppression des fentes externes éventuellement excessives

$fn=120;

nombredraft=floor(douverture/(largfente+largfils));
nombre=(floor(nombredraft/2-suprfentexternes))*2+1;

difference(){
    union(){
        // anneau central MAK ou SCT ===================
        translate([0,0,0])cylinder(d=danneaucentral,h=  epbouchon);
        // RESEAU ======================================
        difference(){ // réseau vertical
            union(){
            translate([0,0,0])cylinder(d=douverture,h=epmask);
            }
            union(){
                translate([0,-douverture/2-5,-1])cube([douverture/2+5,douverture+10,epmask+2]); // tracé du demi-disque
                for (i=[1:nombre]){
                    translate([-douverture/2,-(nombre+1)*(largfente+largfils)/2-largfente/2+i*(largfente+largfils),-1])cube([douverture,largfente,epbouchon+2]);
                }
            }
        }
        difference(){ // réseau incliné droite
            union(){
                translate([0,0,0])cylinder(d=douverture,h=epmask);
            }
            union(){
                // tracé du quart de disque
                translate([-douverture/2-5,-douverture/2-5,-1])cube([douverture/2+5,douverture+10,epmask+2]);
                translate([0,0,-1])cube([douverture/2+5,douverture/2+5,epmask+2]);
                // tracé des fentes
                rotate([0,0,180-angle]){
                    for (i=[2:nombre-1]){
                    translate([-douverture/2,-(nombre+1)*(largfente+largfils)/2-largfente/2+i*(largfente+largfils),-1])cube([douverture,largfente,epbouchon+2]);
                    }
                }
            }
        }
        difference(){ // réseau incliné gauche
            union(){
                translate([0,0,0])cylinder(d=douverture,h=epmask);
            }
            union(){
                // tracé du quart de disque
                translate([-douverture/2-5,-douverture/2-5,-1])cube([douverture/2+5,douverture+10,epmask+2]);
                translate([0,-douverture/2-5,-1])cube([douverture/2+5,douverture/2+5,epmask+2]);
                // tracé des fentes
                rotate([0,0,180+angle]){
                    for (i=[2:nombre-1]){
                    translate([-douverture/2,-(nombre+1)*(largfente+largfils)/2-largfente/2+i*(largfente+largfils),-1])cube([douverture,largfente,epbouchon+2]);
                    }
                }
            }
        }
        // RAIDISSEURS =============================
        translate([0,-largfente,0])cube([douverture/2,2*largfente,epmask]);
        translate([-largfente,-douverture/2,0])cube([largfente*2,douverture,epmask]);
    
        // ANNEAU EXTERIEUR ET BOUCHON ========================
        difference(){
            translate([0,0,0])cylinder(d=dextbouchon,h=profbouchon);
            translate([0,0,epbouchon])cylinder(d=dintbouchon,h=profbouchon);
            translate([0,0,-1])cylinder(d=douverture,h=epbouchon+2);
        }
    }
    // trou central pour MAK ou SCT ================
    translate([0,0,-1])cylinder(d=dinttroucentral,h=epbouchon+2);
}